USE `porta-billing`;
DELIMITER |

--

DROP PROCEDURE IF EXISTS `UPDATE_CUSTOMER`|
CREATE PROCEDURE `UPDATE_CUSTOMER`(IN irep INT(10) unsigned, IN icustomer INT(10) unsigned)
BEGIN
  DECLARE done INT DEFAULT 0;
  DECLARE account VARCHAR(30);
  DECLARE ienv    VARCHAR(30);
  DECLARE pwd     VARCHAR(30);
  DECLARE cur CURSOR FOR SELECT id,i_env,h323_password FROM Accounts where i_customer=icustomer;
  DECLARE CONTINUE HANDLER FOR NOT FOUND SET done = 1;
  OPEN cur;
  read_loop: LOOP
  FETCH cur INTO account,ienv,pwd ;
  IF done THEN
    LEAVE read_loop;
  END IF;
  IF irep NOT IN (3,5,9,12,17) THEN
    IF ienv=1 THEN
      IF account REGEXP '^([0-9]{1,3}[.]){3}[0-9]{1,3}$' THEN
        IF (SELECT 1 FROM `astrad`.ip_customers  WHERE remote_ip = account AND is_node='N') THEN
          DELETE FROM `astrad`.ip_customers WHERE remote_ip = account AND is_node='N';
          INSERT INTO `astrad`.triggers_log (table_name,event,log_time,comment) VALUES ('Customers','UPDATE',NOW(),CONCAT('Delete from ip_customers ',account));
        END IF;
      ELSE
        IF (SELECT 1 FROM `astrad`.users  WHERE username = account) THEN
          DELETE FROM `astrad`.users WHERE username = account;
          INSERT INTO `astrad`.triggers_log (table_name,event,log_time,comment) VALUES ('Customers','UPDATE',NOW(),CONCAT('Delete from users ',account));
        END IF;
      END IF;
    END IF;
  ELSE
    IF ienv=1 THEN
      IF account REGEXP '^([0-9]{1,3}[.]){3}[0-9]{1,3}$' THEN
        INSERT IGNORE INTO `astrad`.ip_customers (remote_ip,is_node) values (account,'N');
        INSERT INTO `astrad`.triggers_log (table_name,event,log_time,comment) VALUES ('Customers','UPDATE',NOW(),CONCAT('Add to ip_customers ',account));
      ELSE
        CALL INSERT_USER(account,pwd,'INSERT','');
        INSERT INTO `astrad`.triggers_log (table_name,event,log_time,comment) VALUES ('Customers','UPDATE',NOW(),CONCAT('Add to users ',account));
      END IF;
    END IF;
  END IF;
  END LOOP;
  CLOSE cur;
  END |
DELIMITER ;

USE `asterisk`;

--
-- Table structure for table `sipdevices`
--

CREATE TABLE IF NOT EXISTS `sipdevices` (
  `id` int(11) NOT NULL auto_increment,
  `name` varchar(80) NOT NULL default '',
  `md5secret` varchar(32) default NULL,
  `host` varchar(15) NOT NULL default 'dynamic',
  `port` smallint(5) unsigned default NULL,
  `context` varchar(80) NOT NULL default 'forbidden',
  `insecure` varchar(15) DEFAULT 'no',
  PRIMARY KEY  (`id`),
  UNIQUE KEY `name` (`name`),
  KEY `name_2` (`name`)
) ;

--
-- Table structure for table `config`
--

CREATE TABLE IF NOT EXISTS `config` (
  `id` int(11) NOT NULL auto_increment,
  `value` text DEFAULT NULL,
  `description` varchar(80)  NULL default '',
  PRIMARY KEY  (`id`)
);

INSERT INTO `config` (value,description) VALUES ('','Deny list for sipdevices');

USE `astrad`;

insert into config values('version','dba006','DBA version');

--
-- Support for user agent in location
--

ALTER TABLE location2 ADD COLUMN useragent varchar(20) default NULL;
ALTER TABLE registration ADD COLUMN useragent varchar(20) default NULL;

--
-- Dumping triggers for table `location2`
--

DELIMITER |
DROP TRIGGER IF EXISTS `Trg_Insert_location2`|
CREATE TRIGGER `Trg_Insert_location2` AFTER INSERT ON `location2` FOR EACH ROW BEGIN
DECLARE IPAD varchar(15) DEFAULT '';
SET IPAD=(SELECT value FROM config WHERE name='ipaddr');
IF NEW.ipaddr IS NOT NULL AND NEW.port IS NOT NULL AND NEW.expires IS NOT NULL AND NEW.dba=IPAD THEN
  INSERT INTO registration (username,dba,domain,ipaddr,port,expires,register,useragent,action) VALUES (NEW.username,NEW.dba,NEW.domain,NEW.ipaddr,NEW.port,NEW.expires,NEW.register,NEW.useragent,'REGISTER');
END IF;
CALL add_multiple_ua(NEW.username,NEW.domain,NEW.ipaddr,NEW.port,"ADD");
END |

--

DROP TRIGGER IF EXISTS `Trg_Update_location2`|
CREATE TRIGGER `Trg_Update_location2` AFTER UPDATE ON `location2` FOR EACH ROW BEGIN
DECLARE IPAD varchar(15) DEFAULT '';
SET IPAD=(SELECT value FROM config WHERE name='ipaddr');
IF NEW.ipaddr IS NOT NULL AND NEW.port IS NOT NULL AND NEW.expires IS NOT NULL AND NEW.dba=IPAD THEN
  INSERT INTO registration (username,dba,domain,ipaddr,port,expires,register,useragent,action) VALUES (NEW.username,NEW.dba,NEW.domain,NEW.ipaddr,NEW.port,NEW.expires,NEW.register,NEW.useragent,'REGISTER');
END IF;
END |

--

DROP TRIGGER IF EXISTS `Trg_Delete_location2`|
CREATE TRIGGER `Trg_Delete_location2` AFTER DELETE ON `location2` FOR EACH ROW BEGIN
DECLARE IPAD varchar(15) DEFAULT '';
SET IPAD=(SELECT value FROM config WHERE name='ipaddr');
IF OLD.dba=IPAD THEN
  INSERT INTO registration (username,dba,domain,ipaddr,port,expires,register,useragent,action) VALUES (OLD.username,OLD.dba,OLD.domain,OLD.ipaddr,OLD.port,OLD.expires,OLD.register,OLD.useragent,'UNREGISTER');
END IF;
CALL add_multiple_ua(OLD.username,OLD.domain,OLD.ipaddr,OLD.port,"DEL");
END |

DROP PROCEDURE IF EXISTS `REGISTER2`|
CREATE PROCEDURE `REGISTER2`(IN USR VARCHAR(80),IN DOM VARCHAR(15),IN IP_ VARCHAR(15), IN PORT_ smallint(5) unsigned, IN EXR DATETIME,IN REG DATETIME,IN UA_ VARCHAR(20))
BEGIN
DECLARE MAXD INT(5) DEFAULT 0;
DECLARE MAXI INT(5) DEFAULT 0;
DECLARE IPAD varchar(15) DEFAULT '';
SET IPAD=(SELECT value FROM config WHERE name='ipaddr');
IF (UA_ is NULL) THEN
  SET UA_='Not Available';
END IF;
IF (SELECT 1 FROM location2 WHERE username=USR AND ipaddr=IP_ AND port=PORT_ AND domain=DOM AND dba=IPAD) THEN
  UPDATE location2 SET expires=EXR,register=REG WHERE username=USR AND ipaddr=IP_ AND port=PORT_ AND domain=DOM AND dba=IPAD;
ELSE
  INSERT INTO location2 (username,domain,dba,ipaddr,port,expires,register,useragent) VALUES (USR,DOM,IPAD,IP_,PORT_,EXR,REG,UA_);
END IF;
INSERT INTO location2_history (start,stop,domain,username,ipaddr,port,count) VALUES (REG,REG,DOM,USR,IP_,PORT_,1) ON DUPLICATE KEY UPDATE count=count+1, stop=REG;
SET MAXI=(SELECT value FROM config WHERE name='max_reg_to_check');
IF (SELECT value FROM config WHERE name='tmp_reg_to_check') < MAXI THEN
    UPDATE config SET value=value+1 WHERE name='tmp_reg_to_check';
ELSE
    UPDATE config SET value=1 WHERE name='tmp_reg_to_check';
    SET MAXD=(SELECT value FROM config WHERE name='day_log_history');
    DELETE FROM location2_history WHERE stop < DATE_ADD(NOW(), INTERVAL -MAXD DAY);
END IF;
END |
DELIMITER ;


--
-- Dumping triggers for table `ip_customers`
--

DELIMITER |
DROP TRIGGER IF EXISTS `Trg_Insert_ip_customers`|
CREATE TRIGGER `Trg_Insert_ip_customers` AFTER INSERT ON `ip_customers` FOR EACH ROW BEGIN
DECLARE DN text DEFAULT '';
DECLARE REQ text DEFAULT '';
DECLARE REQ2 text DEFAULT '';
DECLARE cont VARCHAR(10) DEFAULT '';
IF NEW.is_node='Y' THEN
  SET cont='fromnode';
ELSEIF NEW.is_node='N' THEN
  SET cont='fromhost';
END IF;
IF (SELECT 1 FROM vendors WHERE remote_ip=NEW.remote_ip) IS NULL THEN
    SET REQ=CONCAT("INSERT IGNORE INTO sippeers (name,host,port,context,insecure) VALUES ('",NEW.remote_ip,"','",NEW.remote_ip,"',5060,'",cont,"','port');");
    SET REQ2=CONCAT("INSERT IGNORE INTO sipdevices(name,host,port,context,insecure) VALUES ('",NEW.remote_ip,"','",NEW.remote_ip,"',5060,'",cont,"','port');");
    INSERT INTO request (val) VALUES (REQ);
    INSERT INTO request (val) VALUES (REQ2);
    INSERT INTO triggers_log (table_name,event,log_time,comment) VALUES ('ip_customers','INSERT',NOW(),CONCAT('Add to sippeers and sipdevices ',NEW.remote_ip,' context=',cont));
ELSE
    SET REQ=CONCAT("UPDATE sippeers SET context='",cont,"', insecure='port' WHERE name='",NEW.remote_ip,"' AND context='forbidden';");
    SET REQ2=CONCAT("UPDATE sipdevices SET context='",cont,"', insecure='port' WHERE name='",NEW.remote_ip,"' AND context='forbidden';");
    INSERT INTO request (val) VALUES (REQ);
    INSERT INTO request (val) VALUES (REQ2);
    INSERT INTO triggers_log (table_name,event,log_time,comment) VALUES ('ip_customers','INSERT',NOW(),CONCAT('Set context (',cont,') to ip_customer in sippeers and sipdevices ',NEW.remote_ip));
END IF;
SET DN=(SELECT get_deny());
SET REQ=CONCAT("UPDATE sipusers SET deny='",DN,"';");
SET REQ2=CONCAT("UPDATE config SET value='",DN,"' WHERE id = 1;");
INSERT INTO request (val) VALUES (REQ);
INSERT INTO request (val) VALUES (REQ2);
INSERT INTO triggers_log (table_name,event,log_time,comment) VALUES ('ip_customers','INSERT',NOW(),CONCAT('Update deny in sipusers and config ',NEW.remote_ip));
END |

--

DROP TRIGGER IF EXISTS `Trg_Update_ip_customers`|
CREATE TRIGGER `Trg_Update_ip_customers` AFTER UPDATE ON `ip_customers` FOR EACH ROW BEGIN
DECLARE DN text DEFAULT '';
DECLARE REQ text DEFAULT '';
DECLARE REQ2 text DEFAULT '';
DECLARE cont VARCHAR(10) DEFAULT '';
IF NEW.is_node='Y' THEN
  SET cont='fromnode';
  ELSEIF NEW.is_node='N' THEN
    SET cont='fromhost';
END IF;
SET REQ=CONCAT("UPDATE sippeers SET name='",NEW.remote_ip,"', host='",NEW.remote_ip,"', context='",cont,"' WHERE name='",OLD.remote_ip,"';");
SET REQ2=CONCAT("UPDATE sipdevices SET name='",NEW.remote_ip,"', host='",NEW.remote_ip,"', context='",cont,"' WHERE name='",OLD.remote_ip,"';");
INSERT INTO request (val) VALUES (REQ);
INSERT INTO request (val) VALUES (REQ2);
INSERT INTO triggers_log (table_name,event,log_time,comment) VALUES ('ip_customers','UPDATE',NOW(),CONCAT('update ip customer in sippeers and sipdevices remote_ip=',NEW.remote_ip,' old remote_ip=',OLD.remote_ip));
IF OLD.remote_ip <> NEW.remote_ip THEN
  SET DN=(SELECT get_deny());
  SET REQ=CONCAT("UPDATE sipusers SET deny='",DN,"';");
  SET REQ2=CONCAT("UPDATE config SET value='",DN,"' WHERE id = 1;");
  INSERT INTO request (val) VALUES (REQ);
  INSERT INTO request (val) VALUES (REQ2);
  INSERT INTO triggers_log (table_name,event,log_time,comment) VALUES ('ip_customers','DELETE',NOW(),CONCAT('Update deny in sipusers and sipdevices from ',OLD.remote_ip,' to ',NEW.remote_ip));
END IF;
END |

--

DROP TRIGGER IF EXISTS `Trg_Delete_ip_customers`|
CREATE TRIGGER `Trg_Delete_ip_customers` AFTER DELETE ON `ip_customers` FOR EACH ROW BEGIN
DECLARE DN text DEFAULT '';
DECLARE REQ text DEFAULT '';
DECLARE REQ2 text DEFAULT '';
IF (SELECT 1 FROM vendors WHERE remote_ip=OLD.remote_ip) THEN
  SET REQ=CONCAT("UPDATE sippeers SET context='forbidden', insecure='no' WHERE name='",OLD.remote_ip,"';");
  SET REQ2=CONCAT("UPDATE sipdevices SET context='forbidden', insecure='no' WHERE name='",OLD.remote_ip,"';");
  INSERT INTO request (val) VALUES (REQ);
  INSERT INTO request (val) VALUES (REQ2);
  INSERT INTO triggers_log (table_name,event,log_time,comment) VALUES ('ip_customers','DELETE',NOW(),CONCAT('Update context to forbidden in sippeers and sipdevices ',OLD.remote_ip));
ELSE
  SET REQ=CONCAT("DELETE FROM sippeers WHERE name='",OLD.remote_ip,"';");
  SET REQ2=CONCAT("DELETE FROM sipdevices WHERE name='",OLD.remote_ip,"';");
  INSERT INTO request (val) VALUES (REQ);
  INSERT INTO request (val) VALUES (REQ2);
  INSERT INTO triggers_log (table_name,event,log_time,comment) VALUES ('ip_customers','DELETE',NOW(),CONCAT('Delete from sippeers and sipdevices ',OLD.remote_ip));
END IF;
SET DN=(SELECT get_deny());
SET REQ=CONCAT("UPDATE sipusers SET deny='",DN,"';");
SET REQ2=CONCAT("UPDATE config SET value='",DN,"' WHERE id = 1;");
INSERT INTO request (val) VALUES (REQ);
INSERT INTO request (val) VALUES (REQ2);
INSERT INTO triggers_log (table_name,event,log_time,comment) VALUES ('ip_customers','DELETE',NOW(),CONCAT('Update deny in sipusers and sipdevices ',OLD.remote_ip));
END |

DELIMITER ;

--
-- Dumping triggers for table `vendors`
--

DELIMITER |
DROP TRIGGER IF EXISTS `Trg_Insert_vendors`|
CREATE TRIGGER `Trg_Insert_vendors` AFTER INSERT ON `vendors` FOR EACH ROW BEGIN
DECLARE REQ text DEFAULT '';
IF (SELECT 1 FROM ip_customers WHERE remote_ip=NEW.remote_ip ) IS NULL THEN
  SET REQ=CONCAT("INSERT IGNORE INTO sippeers (name,host,port) VALUES ('",NEW.remote_ip,"','",NEW.remote_ip,"',5060);");
  INSERT INTO request (val) VALUES (REQ);
  SET REQ=CONCAT("INSERT IGNORE INTO sipdevices (name,host,port) VALUES ('",NEW.remote_ip,"','",NEW.remote_ip,"',5060);");
  INSERT INTO request (val) VALUES (REQ);
  INSERT INTO triggers_log (table_name,event,log_time,comment) VALUES ('vendors','INSERT',NOW(),CONCAT('Add vendor to sippeers and sipdevices ',NEW.remote_ip));
ELSE
  INSERT INTO triggers_log (table_name,event,log_time,comment) VALUES ('vendors','INSERT',NOW(),CONCAT('Vendor already exist on sippeers/sipdevices (ip existe on ip_customers)',NEW.remote_ip));
END IF;
END |

--

DROP TRIGGER IF EXISTS `Trg_Update_vendors`|
CREATE TRIGGER `Trg_Update_vendors` AFTER UPDATE ON `vendors` FOR EACH ROW BEGIN
DECLARE REQ text DEFAULT '';
SET REQ=CONCAT("UPDATE sippeers SET name='",NEW.remote_ip,"', host='",NEW.remote_ip,"' WHERE name='",OLD.remote_ip,"' AND context='forbidden';");
INSERT INTO request (val) VALUES (REQ);
SET REQ=CONCAT("UPDATE sipdevices SET name='",NEW.remote_ip,"', host='",NEW.remote_ip,"' WHERE name='",OLD.remote_ip,"' AND context='forbidden';");
INSERT INTO request (val) VALUES (REQ);
INSERT INTO triggers_log (table_name,event,log_time,comment) VALUES ('vendors','UPDATE',NOW(),CONCAT('Update sippeers and sipdevices remote_ip=',NEW.remote_ip,' old remote_ip=',OLD.remote_ip));
END |

--

DROP TRIGGER IF EXISTS `Trg_Delete_vendors`|
CREATE TRIGGER `Trg_Delete_vendors` AFTER DELETE ON `vendors` FOR EACH ROW BEGIN
DECLARE REQ text DEFAULT '';
SET REQ=CONCAT("DELETE FROM sippeers WHERE name='",OLD.remote_ip,"' AND context='forbidden';");
INSERT INTO request (val) VALUES (REQ);
SET REQ=CONCAT("DELETE FROM sipdevices WHERE name='",OLD.remote_ip,"' AND context='forbidden';");
INSERT INTO request (val) VALUES (REQ);
INSERT INTO triggers_log (table_name,event,log_time,comment) VALUES ('vendors','DELETE',NOW(),CONCAT('Delete vendor from sippeers and sipdevices ',OLD.remote_ip));
END |

DELIMITER ;

--
-- Dumping triggers for table `users`
--

DELIMITER |
DROP TRIGGER IF EXISTS `Trg_Insert_users`|
CREATE TRIGGER `Trg_Insert_users` AFTER INSERT ON `users` FOR EACH ROW BEGIN
DECLARE DN text DEFAULT '';
DECLARE REQ text DEFAULT '';
SET DN=(SELECT get_deny());
SET REQ=CONCAT("INSERT IGNORE INTO sipusers (name,md5secret,deny) VALUES ('",NEW.username,"','",NEW.md5secret,"','",DN,"');");
INSERT INTO request (val) VALUES (REQ);
SET REQ=CONCAT("INSERT IGNORE INTO sipdevices (name,md5secret,context,host) VALUES ('",NEW.username,"','",NEW.md5secret,"','fromaccount','dynamic');");
INSERT INTO request (val) VALUES (REQ);
INSERT INTO triggers_log (table_name,event,log_time,comment) VALUES ('users','INSERT',NOW(),CONCAT('Add to sipusers and sipdevices ',NEW.username));
SET REQ=CONCAT("INSERT IGNORE INTO sippeers (name,md5secret) VALUES ('",NEW.username,"','",NEW.md5secret,"');");
INSERT INTO request (val) VALUES (REQ);
INSERT INTO triggers_log (table_name,event,log_time,comment) VALUES ('users','INSERT',NOW(),CONCAT('Add to sippeers ',NEW.username));
END |

--

DROP TRIGGER IF EXISTS `Trg_Update_users`|
CREATE TRIGGER `Trg_Update_users` AFTER UPDATE ON `users` FOR EACH ROW BEGIN
DECLARE REQ text DEFAULT '';
SET REQ=CONCAT("UPDATE sipusers SET name='",NEW.username,"', md5secret='",NEW.md5secret,"' WHERE name='",OLD.username,"';");
INSERT INTO request (val) VALUES (REQ);
SET REQ=CONCAT("UPDATE sipdevices SET name='",NEW.username,"', md5secret='",NEW.md5secret,"' WHERE name='",OLD.username,"';");
INSERT INTO request (val) VALUES (REQ);
INSERT INTO triggers_log (table_name,event,log_time,comment) VALUES ('users','UPDATE',NOW(),CONCAT('Update sipusers and sipdevices new username=',NEW.username,' old username=',OLD.username));
SET REQ=CONCAT("UPDATE sippeers SET name='",NEW.username,"', md5secret='",NEW.md5secret,"' WHERE name='",OLD.username,"';");
INSERT INTO request (val) VALUES (REQ);
INSERT INTO triggers_log (table_name,event,log_time,comment) VALUES ('users','UPDATE',NOW(),CONCAT('update sippeers user=',NEW.username,' old username=',OLD.username));
END |

--

DROP TRIGGER IF EXISTS `Trg_Delete_users`|
CREATE TRIGGER `Trg_Delete_users` AFTER DELETE ON `users` FOR EACH ROW BEGIN
DECLARE REQ text DEFAULT '';
SET REQ=CONCAT("DELETE FROM sipusers WHERE name='",OLD.username,"';");
INSERT INTO request (val) VALUES (REQ);
SET REQ=CONCAT("DELETE FROM sipdevices WHERE name='",OLD.username,"';");
INSERT INTO request (val) VALUES (REQ);
INSERT INTO triggers_log (table_name,event,log_time,comment) VALUES ('users','DELETE',NOW(),CONCAT('Delete from sipusers ',OLD.username));
SET REQ=CONCAT("DELETE FROM sippeers WHERE name='",OLD.username,"';");
INSERT INTO request (val) VALUES (REQ);
INSERT INTO triggers_log (table_name,event,log_time,comment) VALUES ('users','DELETE',NOW(),CONCAT('Delete from sippeers ',OLD.username));
END |

DELIMITER ;

USE `porta-billing`;
--
-- Table structure for table `Destinations`
--

CREATE TABLE Destinations (
  i_dest int(10) unsigned NOT NULL auto_increment,
  destination char(16) NOT NULL default '',
  iso_3166_1_a2 char(2) default '',
  i_country_subdivision smallint(5) unsigned default NULL,
  i_time_zone int(10) unsigned default NULL,
  description char(64) NOT NULL default '',
  i_group int(10) unsigned default '0',
  i_env tinyint(1) unsigned default '1',
  dest_type char(20) default NULL,
  PRIMARY KEY  (i_dest),
  UNIQUE KEY destination (destination,i_env),
  KEY iso_3166_1_a2 (iso_3166_1_a2),
  KEY Destinations_i_group (i_group),
  KEY dest_type (dest_type),
  KEY env_dest_i_dest_iso (destination,i_env,i_dest,iso_3166_1_a2)
) TYPE=InnoDB;

--
-- Table structure for table `Active_Calls`
--

CREATE TABLE Active_Calls (
  i_active_callleg int(10) unsigned NOT NULL auto_increment,
  h323_conf_id char(36) default NULL,
  call_id char(64) default NULL,
  i_env int(10) unsigned NOT NULL default '0',
  i_node int(10) unsigned NOT NULL default '0',
  call_type enum('VoIP','Telephony') NOT NULL default 'VoIP',
  call_origin enum('answer','originate') NOT NULL default 'answer',
  port char(32) NOT NULL default '',
  connect_time datetime NOT NULL default '0000-00-00 00:00:00',
  update_time datetime NOT NULL default '0000-00-00 00:00:00',
  disconnect_time datetime default NULL,
  CLI char(32) default NULL,
  CLD char(32) default NULL,
  i_account int(10) unsigned default NULL,
  i_customer int(10) unsigned default NULL,
  i_connection int(10) unsigned default NULL,
  PRIMARY KEY  (i_active_callleg)
) TYPE=InnoDB;

--
-- Table structure for table `Follow_Me`
--

CREATE TABLE Follow_Me (
  i_follow_me int(10) unsigned NOT NULL auto_increment,
  i_account int(10) unsigned NOT NULL default '0',
  mode enum('Never','Always','Unavail') default NULL,
  sequence enum('Order','Random','Simultaneous') default NULL,
  timeout smallint(4) unsigned default NULL,
  PRIMARY KEY  (i_follow_me),
  UNIQUE KEY i_account (i_account)
) TYPE=InnoDB;

--
-- Table structure for table `Rates`
--

CREATE TABLE Rates (
  i_tariff int(10) unsigned NOT NULL default '0',
  i_dest int(10) unsigned NOT NULL default '0',
  i_rate int(10) unsigned NOT NULL auto_increment,
  interval_1 smallint(5) unsigned NOT NULL default '1',
  interval_n smallint(5) unsigned NOT NULL default '1',
  price_1 decimal(15,5) unsigned default NULL,
  price_n decimal(15,5) unsigned default NULL,
  op_interval_1 smallint(5) unsigned NOT NULL default '1',
  op_interval_n smallint(5) unsigned NOT NULL default '1',
  op_price_1 decimal(15,5) unsigned default NULL,
  op_price_n decimal(15,5) unsigned default NULL,
  effective_from datetime NOT NULL default '0000-00-00 00:00:00',
  hidden char(1) NOT NULL default 'N',
  discontinued char(1) NOT NULL default 'N',
  forbidden char(1) NOT NULL default 'N',
  preference tinyint(1) unsigned NOT NULL default '5',
  huntstop char(1) NOT NULL default 'N',
  lot_time int(10) default NULL,
  formula varchar(255) default NULL,
  fake_rate char(1) NOT NULL default 'Y',
  i_master_rate int(10) unsigned default NULL,
  route_category tinyint(1) unsigned default NULL,
  op_route_category tinyint(1) unsigned default NULL,
  op_preference tinyint(1) unsigned default NULL,
  op_huntstop char(1) default 'N',
  PRIMARY KEY  (i_rate),
  KEY Rates_dest_index (i_dest),
  KEY Rates_i_tariff (i_tariff),
  KEY Rates_effective_from (effective_from),
  KEY master_rate (i_master_rate),
  KEY Rates_route_category (route_category,op_route_category),
  KEY tar_dest_effrom_rate (i_tariff,i_dest,effective_from,discontinued,i_rate)
) TYPE=InnoDB PACK_KEYS=1;

--
-- Table structure for table `Service_Attribute_Values`
--

CREATE TABLE Service_Attribute_Values (
  i_savalue int(10) NOT NULL auto_increment,
  i_sattribute int(10) NOT NULL default '0',
  i_foreign int(10) NOT NULL default '0',
  value char(255) default NULL,
  ord tinyint(4) default NULL,
  PRIMARY KEY  (i_savalue),
  KEY savalue_sattribute (i_sattribute,i_foreign)
) TYPE=MyISAM;


