# dba006.pp

# module astrad
# v 004
#
# Can be used as an upgrade from v 003
#
# Created on 110311 by yannick.vaucher@switzernet.com
#

import "mysql-server.pp"
import "postfix.pp"
import "perl.pp"

class dba006{

	$module_name = "dba006"
	include mysql-server
	include postfix	
        include perl

	package{[libdbi-perl, libdbd-mysql-perl, ntp, ngrep]:
		ensure      => installed,
                require     => Package["mysql-server"],
	}

        define packagesCPAN {
                perl::installCPAN {    ["YAML",
                                        "Config::IniFiles",
                                        "List::Util",
                                        "Sys::Syslog",
                                        "MIME::Lite",
                                        "Date::Manip"]:
                }
        }

        packagesCPAN{"mysql":
                require     => Package["mysql-server"]
        }


        file { "/etc/dba":
                ensure      => directory,
        }

        file{"/etc/dba/setup-mysql-replication.pl":
                ensure      => file,
                owner       => root,
                group       => root,
                mode        => 755,
                recurse     => true,
                replace     => true,
                source      => "puppet:///$module_name/setup-mysql-replication.pl",
                require     => File["/etc/dba"]
        }

       file{"/etc/dba/exec-registration.pl":
                ensure      => file,
                owner       => root,
                group       => root,
                mode        => 755,
                recurse     => true,
                replace     => true,
                source      => "puppet:///$module_name/exec-registration.pl",
                require     => File["/etc/dba"]
        }

       file{"/etc/dba/exec-replication.pl":
                ensure      => file,
                owner       => root,
                group       => root,
                mode        => 755,
                recurse     => true,
                replace     => true,
                source      => "puppet:///$module_name/exec-replication.pl",
                require     => File["/etc/dba"]
        }

        file{"/etc/cron.d/dba":
                ensure      => file,
                owner       => root,
                group       => root,
                mode        => 755,
                recurse     => true,
                replace     => true,
                source      => "puppet:///$module_name/dba",
        }

        file{"/etc/dba/110718-dba.sql":
                ensure      => file,
                owner       => root,
                group       => root,
                mode        => 644,
                replace     => true,
                content     => template("$module_name/110718-dba.sql.erb"),
                require     => File["/etc/dba"]
        }

        file{"/etc/dba/setup-mysql-replication.conf":
                ensure      => file,
                owner       => root,
                group       => root,
                mode        => 644,
                replace     => true,
                content     => template("$module_name/setup-mysql-replication.conf.erb"),
                require     => File["/etc/dba"]
        }
        
        file{"/etc/dba/110811-update.sql":
                ensure      => file,
                owner       => root,
                group       => root,
                mode        => 755,
                recurse     => true,
                replace     => true,
                source      => "puppet:///$module_name/110811-update.sql",
                require     => File["/etc/dba"]
        }

        file{"/etc/dba/111102-update.sql":
                ensure      => file,
                owner       => root,
                group       => root,
                mode        => 755,
                recurse     => true,
                replace     => true,
                source      => "puppet:///$module_name/111102-update.sql",
                require     => File["/etc/dba"]
        }

        file{"/etc/dba/111207-update.sql":
                ensure      => file,
                owner       => root,
                group       => root,
                mode        => 755,
                recurse     => true,
                replace     => true,
                source      => "puppet:///$module_name/111207-update.sql",
                require     => File["/etc/dba"]
        }

        file{"/etc/dba/Lister.pm":
                ensure      => file,
                owner       => root,
                group       => root,
                mode        => 755,
                recurse     => true,
                replace     => true,
                source      => "puppet:///$module_name/Lister.pm",
                require     => File["/etc/dba"]
        }

        exec { "setup mysql replication":
                command     => "/etc/dba/setup-mysql-replication.pl > /dev/null 2>&1",
                subscribe   => [File["/etc/dba/setup-mysql-replication.conf"], File["/etc/dba/110718-dba.sql"], File["/etc/dba/110811-update.sql"], File["/etc/dba/111102-update.sql"], File["/etc/dba/111207-update.sql"]],
                refreshonly => true,
                timeout     => 0,
                require     => [ File["/etc/dba/setup-mysql-replication.conf"], File["/etc/dba/110718-dba.sql"], File["/etc/dba/110811-update.sql"], File["/etc/dba/111102-update.sql"], File["/etc/dba/111207-update.sql"], PackagesCPAN["mysql"] , File["/etc/dba/setup-mysql-replication.pl"] ]
        }
}

